<?php namespace EscapeWork\Manager\Medias\Services;

use EscapeWork\Manager\Medias\Models\Media;
use EscapeWork\Manager\Medias\Contracts\Mediable;

use Illuminate\Filesystem\Filesystem;

class MediasDestroyerService
{

    /**
     * @var EscapeWork\Manager\Medias\Models\Media
     */
    protected $media;

    /**
     * @var Illuminate\Filesystem\Filesystem
     */
    protected $files;

    public function __construct(Media $media, Filesystem $files)
    {
        $this->media = $media;
        $this->files = $files;
    }

    public function removeFromSpecificMedias(array $mediaIds)
    {
        if (count($mediaIds) === 0) {
            return;
        }

        return $this->removeFromMedias($mediaIds);
    }

    public function removeFromMedias($model)
    {
        if (is_array($model)) {
            $medias = $this->media->whereIn('id', $model)->get();
        } else {
            $medias = $this->media
                 ->where('media_model', '=', get_class($model))
                 ->where('model_id', '=', $model->id)
                 ->get();
        }

        foreach ($medias as $media) {
            $media->delete();
        }
    }

    public function removeFromModel($model, $config)
    {
        foreach ($config['fields'] as $field) {
            if ($this->files->exists($file = $config['dir'] . '/' . $model->{$field})) {
                $this->files->delete($file);
            }
        }
    }
}
